==> grizzly-http-server-4.0.1-sources.jar: module-info.java <==
/*
 * Copyright (c) 2011, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

module org.glassfish.grizzly.http.server {
    
    exports org.glassfish.grizzly.http.server;
    exports org.glassfish.grizzly.http.server.accesslog;
    exports org.glassfish.grizzly.http.server.filecache;
    exports org.glassfish.grizzly.http.server.http2;
    exports org.glassfish.grizzly.http.server.io;
    exports org.glassfish.grizzly.http.server.jmxbase;
    exports org.glassfish.grizzly.http.server.naming;
    exports org.glassfish.grizzly.http.server.util;

    opens org.glassfish.grizzly.http.server;
    opens org.glassfish.grizzly.http.server.accesslog;
    opens org.glassfish.grizzly.http.server.filecache;
    opens org.glassfish.grizzly.http.server.http2;
    opens org.glassfish.grizzly.http.server.io;
    opens org.glassfish.grizzly.http.server.jmxbase;
    opens org.glassfish.grizzly.http.server.naming;
    opens org.glassfish.grizzly.http.server.util;
    
    requires java.logging;
    requires org.glassfish.grizzly.http;
    requires org.glassfish.grizzly;
    
    requires gmbal;
    requires org.glassfish.external.management.api;
    requires pfl.basic;
    requires pfl.tf;
    requires org.objectweb.asm;
    requires pfl.dynamic;
    requires org.objectweb.asm.util;
    requires org.objectweb.asm.tree;
    requires org.objectweb.asm.tree.analysis;
    requires pfl.basic.tools;
    requires pfl.tf.tools;
    requires org.objectweb.asm.commons;
}

==> grizzly-http-server-4.0.2-sources.jar: module-info.java <==
/*
 * Copyright (c) 2011, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

module org.glassfish.grizzly.http.server {
    
    exports org.glassfish.grizzly.http.server;
    exports org.glassfish.grizzly.http.server.accesslog;
    exports org.glassfish.grizzly.http.server.filecache;
    exports org.glassfish.grizzly.http.server.http2;
    exports org.glassfish.grizzly.http.server.io;
    exports org.glassfish.grizzly.http.server.jmxbase;
    exports org.glassfish.grizzly.http.server.naming;
    exports org.glassfish.grizzly.http.server.util;

    opens org.glassfish.grizzly.http.server;
    opens org.glassfish.grizzly.http.server.accesslog;
    opens org.glassfish.grizzly.http.server.filecache;
    opens org.glassfish.grizzly.http.server.http2;
    opens org.glassfish.grizzly.http.server.io;
    opens org.glassfish.grizzly.http.server.jmxbase;
    opens org.glassfish.grizzly.http.server.naming;
    opens org.glassfish.grizzly.http.server.util;
    
    requires java.logging;
    requires org.glassfish.grizzly.http;
    requires org.glassfish.grizzly;
    
    requires static gmbal;
    requires static org.glassfish.external.management.api;
    requires static pfl.basic.tools;
    requires static pfl.dynamic;
    requires static pfl.basic;
    requires static pfl.tf;
    requires static pfl.tf.tools;
    requires static org.objectweb.asm;
    requires static org.objectweb.asm.util;
    requires static org.objectweb.asm.tree;
    requires static org.objectweb.asm.tree.analysis;
    requires static org.objectweb.asm.commons;
}
